<p>
  [{{ server.last_updated }}] Status on Server <strong>{{ server.name }}</strong> at {{ server.url }} has transitioned to {{ status.STATUS }}.
</p>

{% if status.STATUS == 'OK' %}
 <p>Good job!</p>
{% endif %}
<p>
  {{ status.content }}
</p>
